==> xorg-edit_06.08.02_src.tar.gz: xorg-edit/sources/display.h <==
#ifndef DISPLAY_H
#define DISPLAY_H

// **************************************
// Header Files
// **************************************

#include "global.h"
#include "optionList.h"

// **************************
// Class Definition
// **************************

class display
{
public:
  display(void);   // constructor
  ~display(void);   // destructor
  display(const display &dis); // copy constructor

  display operator=(const display &dis); // copy constructor

  void AddComment(const wxString& com);   // set comment
  void SetDepth(const wxString& dd, const wxString& com=wxEmptyString);     // set depth
  void SetViewPort(const wxString& vw, const wxString& com=wxEmptyString);     // set viewport
  void SetVirtual(const wxString& vi, const wxString& com=wxEmptyString);     // set virtual

  const wxArrayString& GetComment(void) const;         // return comment
  const wxString& GetDepth(void) const;         // return depth
  const wxString& GetViewPort(void) const;         // return viewport
  const wxString& GetVirtual(void) const;         // return virtual
  const wxString& GetDepthComment(void) const;         // return depth comment
  const wxString& GetViewPortComment(void) const;         // return viewport comment
  const wxString& GetVirtualComment(void) const;         // return virtual comment

  void RemoveOption(const unsigned int index);    // remove option
  void AddOption(const option &opt);              // add option
  void SetOption(const unsigned int index, const option &opt); // set option

  option& GetOptionE(const unsigned int index);                // get option
  const option& GetOption(const unsigned int index) const;     // get option
  unsigned int GetOptionSize(void) const;                      // return size of options

  void RemoveMode(const unsigned int index);   // remove mode
  void AddMode(const wxString& mode);          // add mode
  void SetModeComment(const wxString& com);   // set mode comment
  void SetMode(const unsigned int index, const wxString& mode);  // set mode

  const wxString& GetMode(const unsigned int index) const;        // get mode
  const wxString& GetModeComment(void) const;        // get mode comment
  unsigned int GetModeSize(void) const;                    // return number of modes

  void Clear(void);          // clear everything

private:
  wxString depth;        // depth
  wxString viewport;     // view port
  wxArrayString modes;   // screen modes
  wxString virtualE;     // virtual entry

  // Note: Any additional settings will not be recognized like:
  // FbBpp, Weight, Visual, Black, White.

  wxArrayString comment;
  wxString depthComment;
  wxString viewportComment;
  wxString modesComment;
  wxString virtualEComment;

  optionList options;
};

#endif // DISPLAY_H

==> xorg-edit_06.10.08_src.tar.gz: xorg-edit/sources/display.h <==
#ifndef DISPLAY_H
#define DISPLAY_H

// **************************************
// Header Files
// **************************************

#include "global.h"
#include "optionlist.h"

// **************************
// Class Definition
// **************************

class Display
{
public:
  Display(void);   // constructor
  ~Display(void);   // destructor
  Display(const Display &dis); // copy constructor

  Display& operator=(const Display &dis); // copy constructor

  void AddComment(const wxString& com);   // set comment
  void SetDepth(const wxString& dd, const wxString& com=wxEmptyString);     // set depth
  void SetViewPort(const wxString& vw, const wxString& com=wxEmptyString);     // set viewport
  void SetVirtual(const wxString& vi, const wxString& com=wxEmptyString);     // set virtual

  const wxArrayString& GetComment(void) const;         // return comment
  const wxString& GetDepth(void) const;         // return depth
  const wxString& GetViewPort(void) const;         // return viewport
  const wxString& GetVirtual(void) const;         // return virtual
  const wxString& GetDepthComment(void) const;         // return depth comment
  const wxString& GetViewPortComment(void) const;         // return viewport comment
  const wxString& GetVirtualComment(void) const;         // return virtual comment

  void RemoveOption(const int index);    // remove option
  void AddOption(const Option &opt);              // add option
  void SetOption(const int index, const Option &opt); // set option

  Option& GetOption(const int index);                // get option
  const Option& GetOption(const int index) const;     // get option
  const int GetOptionSize(void) const;                      // return size of options

  void RemoveMode(const int index);   // remove mode
  void AddMode(const wxString& mode);          // add mode
  void SetModeComment(const wxString& com);   // set mode comment
  void SetMode(const int index, const wxString& mode);  // set mode

  const wxString& GetMode(const int index) const;        // get mode
  const wxString& GetModeComment(void) const;        // get mode comment
  const int GetModeSize(void) const;                    // return number of modes

  void Clear(void);          // clear everything

private:
  wxString depth;        // depth
  wxString viewport;     // view port
  wxArrayString modes;   // screen modes
  wxString virtualE;     // virtual entry

  // Note: Any additional settings will not be recognized like:
  // FbBpp, Weight, Visual, Black, White.

  wxArrayString comment;
  wxString depthComment;
  wxString viewportComment;
  wxString modesComment;
  wxString virtualEComment;

  OptionList options;
};

#endif // DISPLAY_H
